==> openx-2.6.0.tar.bz2: openx-2.6.0/plugins/reports/standard/_lang/zh_CN.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.6                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: zh_CN.php 22929 2008-07-21 14:01:02Z david.keen@openx.org $
*/
    $words = array(
        'Advertiser' => "广告主",
        'Campaign' => "广告项目",
        'Standard Reports' => "标准报告",
        'Advertising Analysis Report' => "广告分析报告",
        'This report shows a breakdown of advertising for a particular advertiser or publisher, by day, campaign, and zone.' => "本报告按天、广告或版位显示某广告主或者发布商广告业务明细表.",
        'Campaign Analysis Report' => "广告活动分析报告",
        'This report shows a breakdown of advertising for a particular campaign, by day, banner, and zone.' => "本报告按天、广告或版位显示某广告主特定广告活动明细表.",
        'Conversion Tracking Report' => "转换跟踪报告",
        'A detailed breakdown of all conversion activity by advertiser or publisher.' => "广告主或发布商的转换活动明细",
        'Period' => "周期",
        'Limitations' => "限制条件",
        'Worksheets' => "工作表",
        'Ad Breakdown' => "广告明细",
        'Campaign Breakdown' => "广告活动明细",
        'Campaign Delivery' => "广告活动投放",
        'Connection Detail' => "链接数详细信息",
        'Connection Summary by Day' => "按天统计连接数",
        'Daily Breakdown' => "每日明细",
        'Performance by Day' => "按天统计表现",
        'Variable Summary by Day' => "根据天数统计",
        'Variable Summary by Variable' => "根据变量统计",
        'Zone Breakdown' => "版位明细",
        'Advertiser Name' => "广告主名称",
        'All Advertisers' => "所有广告主",
        'Anonymous Advertisers' => "匿名广告主",
        'Publisher' => "发布商",
        'Publisher Name' => "发布商名称",
        'All Publishers' => "所有发布商",
        'Anonymous Publishers' => "匿名发布商",
        'Impression' => "曝光",
        'Click' => "点击",
        'Manual' => "手册",
        'Arrival' => "到达",
        'Unknown' => "未知",
        'Pending' => "未决",
        'Approved' => "允许",
        'Duplicate' => "重复",
        'Disapproved' => "不允许",
        'On Hold' => "搁置",
        'Ignored' => "忽略",
        'Booked Impressions' => "版位曝光数",
        'Delivered Impressions' => "所需曝光数",
    );
?>

==> openx-2.6.2.tar.bz2: openx-2.6.2/plugins/reports/standard/_lang/zh_CN.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.6                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: zh_CN.php 24736 2008-08-27 11:30:00Z andrew.hill $
*/
    $words = array(
        'Advertiser' => "广告主",
        'Campaign' => "广告项目",
        'Standard Reports' => "标准报告",
        'Advertising Analysis Report' => "广告分析报告",
        'This report shows a breakdown of advertising for a particular advertiser or publisher, by day, campaign, and zone.' => "本报告按天、广告或版位显示某广告主或者发布商广告业务明细表.",
        'Campaign Analysis Report' => "广告活动分析报告",
        'This report shows a breakdown of advertising for a particular campaign, by day, banner, and zone.' => "本报告按天、广告或版位显示某广告主特定广告活动明细表.",
        'Conversion Tracking Report' => "转换跟踪报告",
        'A detailed breakdown of all conversion activity by advertiser or publisher.' => "广告主或发布商的转换活动明细",
        'Period' => "周期",
        'Limitations' => "限制条件",
        'Worksheets' => "工作表",
        'Ad Breakdown' => "广告明细",
        'Campaign Breakdown' => "广告活动明细",
        'Campaign Delivery' => "广告活动投放",
        'Connection Detail' => "链接数详细信息",
        'Connection Summary by Day' => "按天统计连接数",
        'Daily Breakdown' => "每日明细",
        'Performance by Day' => "按天统计表现",
        'Variable Summary by Day' => "根据天数统计",
        'Variable Summary by Variable' => "根据变量统计",
        'Zone Breakdown' => "版位明细",
        'Advertiser Name' => "广告主名称",
        'All Advertisers' => "所有广告主",
        'Anonymous Advertisers' => "匿名广告主",
        'Publisher' => "发布商",
        'Publisher Name' => "发布商名称",
        'All Publishers' => "所有发布商",
        'Anonymous Publishers' => "匿名发布商",
        'Impression' => "曝光",
        'Click' => "点击",
        'Manual' => "手册",
        'Arrival' => "到达",
        'Unknown' => "未知",
        'Pending' => "未决",
        'Approved' => "允许",
        'Duplicate' => "重复",
        'Disapproved' => "不允许",
        'On Hold' => "搁置",
        'Ignored' => "忽略",
        'Start Date' => "起始日期",
        'End Date' => "结束日期",
        'Campaign Delivery Report' => "项目发送报告",
        'This report shows delivery statistics for all campaigns which were live during the specified period, highlighting campaigns which are underperforming.' => "此报告显示了在给定期限中对所有项目的发送统计信息, 其中未达成指标的项目被高亮.",
        'Booked Impressions' => "预定曝光数",
        'Delivered Impressions' => "实际曝光数",
        '% Complete' => "%完成",
        'Overall +/-' => "总体 +/-",
        'Current +/-' => "当前 +/-",
        'Missing Sheets' => "没有为报告选定工作表",
        'Unknown error code' => "未定义的错误代码#",
    );
?>
